[![Build Status](https://travis-ci.com/edmundsj/pyNutrient.svg?branch=main)](https://travis-ci.com/edmundsj/pyNutrient) [![Coverage Status](https://coveralls.io/repos/github/edmundsj/pyNutrient/badge.svg?branch=main)](https://coveralls.io/github/edmundsj/pyNutrient?branch=main) [![Documentation Status](https://readthedocs.org/projects/pyNutrient/badge/?version=latest)](https://rcwa.readthedocs.io/en/latest/?badge=latest)[![PyPI version](https://badge.fury.io/py/pyNutrient.svg)](https://badge.fury.io/py/pyNutrient)

Getting Started
================
Installation
--------------
The recommended way to install this software is with `pip`:

```
pip install rcwa
```

And that's it! 

Hello World Program
----------------------
To run a simple example, run:

```
python -m rcwa.examples.bragg_mirror
```

Features
==========

Documentation
================
This  project is documented on [Read The Docs](https://pyNutrient.readthedocs.io/en/latest/). For additional information, including downloading examples, you can view this project on [github](https://github.com/edmundsj/RCWA). 

Author: Jordan Edmunds, UC Irvine Alumnus, UC Berkeley Ph.D. Student

Date Started: 2020/01/05

License
=========
This project is distributed under the [MIT license](https://mit-license.org/).

